# IndicatorContext

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**entry_id** | **str** |  | [optional] 
**indicator** | [**IocObject**](IocObject.md) |  | [optional] 
**investigation_id** | **str** |  | [optional] 
**seen_now** | **bool** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


